==> release-1.0.tar.gz: components-contrib/tests/conformance/utils/utils.go <==
// ------------------------------------------------------------
// Copyright (c) Microsoft Corporation and Dapr Contributors.
// Licensed under the MIT License.
// ------------------------------------------------------------

package utils

import (
	"context"
	"fmt"
	"io/ioutil"
	"net/http"
	"os"
	"os/signal"
	"time"

	"github.com/dapr/dapr/pkg/logger"
	"github.com/gorilla/mux"
	"k8s.io/apimachinery/pkg/util/sets"
)

type CommonConfig struct {
	ComponentType string
	ComponentName string
	AllOperations bool
	Operations    sets.String
}

type server struct {
	Data []byte
}

// nolint:gochecknoglobals
var (
	s          server
	testLogger = logger.NewLogger("utils")
)

func (cc CommonConfig) HasOperation(operation string) bool {
	return cc.AllOperations || cc.Operations.Has(operation)
}

func (cc CommonConfig) CopyMap(config map[string]string) map[string]string {
	m := map[string]string{}
	for k, v := range config {
		m[k] = v
	}

	return m
}

func StartHTTPServer(port int, ready chan bool) {
	s = server{}
	srv := http.Server{
		Addr:    fmt.Sprintf(":%d", port),
		Handler: appRouter(),
	}

	testLogger.Info(("Starting HTTP Server"))
	go func() {
		if err := srv.ListenAndServe(); err != nil {
			testLogger.Errorf("Error with http server: %s", err.Error())
		}
	}()

	testLogger.Info(("Registering Signal"))
	stop := make(chan os.Signal, 1)
	signal.Notify(stop, os.Interrupt)
	ready <- true
	testLogger.Info(("Waiting to stop Server"))
	<-stop
	testLogger.Info(("Stopping Server"))

	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
	defer cancel()
	if err := srv.Shutdown(ctx); err != nil {
		testLogger.Errorf("Error shutting down http server: %s", err.Error())
	}
}

func appRouter() *mux.Router {
	router := mux.NewRouter().StrictSlash(true)

	router.HandleFunc("/call", handleCall).Methods("POST")

	router.Use(mux.CORSMethodMiddleware(router))

	return router
}

func handleCall(w http.ResponseWriter, r *http.Request) {
	switch r.Method {
	case "POST":
		s.handlePost(r)
	case "GET":
		w.Write(s.handleGet())
	default:
		w.WriteHeader(http.StatusInternalServerError)
	}
}

func (s *server) handleGet() []byte {
	return s.Data
}

func (s *server) handlePost(r *http.Request) {
	data, err := ioutil.ReadAll(r.Body)
	defer r.Body.Close()

	if err == nil {
		s.Data = data
	}
}

==> release-1.1.tar.gz: components-contrib/tests/conformance/utils/utils.go <==
// ------------------------------------------------------------
// Copyright (c) Microsoft Corporation and Dapr Contributors.
// Licensed under the MIT License.
// ------------------------------------------------------------

package utils

import (
	"fmt"
	"io/ioutil"
	"net"
	"net/http"
	"net/http/httptest"
	"os"
	"os/signal"

	"github.com/gorilla/mux"

	"github.com/dapr/dapr/pkg/logger"
)

type CommonConfig struct {
	ComponentType string
	ComponentName string
	AllOperations bool
	Operations    map[string]struct{}
}

type server struct {
	Data []byte
}

// nolint:gochecknoglobals
var (
	s          server
	testLogger = logger.NewLogger("utils")
)

func (cc CommonConfig) HasOperation(operation string) bool {
	if cc.AllOperations {
		return true
	}
	_, exists := cc.Operations[operation]

	return exists
}

func (cc CommonConfig) CopyMap(config map[string]string) map[string]string {
	m := map[string]string{}
	for k, v := range config {
		m[k] = v
	}

	return m
}

func StartHTTPServer(port int, ready chan bool) {
	l, err := net.Listen("tcp", fmt.Sprintf(":%d", port))
	if err != nil {
		testLogger.Errorf("Error starting test HTTP serer: %v", err)

		return
	}

	testLogger.Info(("Starting HTTP Server"))
	ts := httptest.NewUnstartedServer(appRouter())
	// NewUnstartedServer creates a listener. Close that listener and replace
	// with the one we created.
	ts.Listener.Close()
	ts.Listener = l

	// Start the server.
	ts.Start()
	defer ts.Close()

	ready <- true

	testLogger.Info(("Registering Signal"))
	stop := make(chan os.Signal, 1)
	signal.Notify(stop, os.Interrupt)

	testLogger.Info(("Waiting to stop Server"))
	<-stop
	testLogger.Info(("Stopping Server"))
}

func appRouter() *mux.Router {
	router := mux.NewRouter().StrictSlash(true)

	router.HandleFunc("/call", handleCall).Methods("POST")

	router.Use(mux.CORSMethodMiddleware(router))

	return router
}

func handleCall(w http.ResponseWriter, r *http.Request) {
	switch r.Method {
	case "POST":
		s.handlePost(r)
	case "GET":
		w.Write(s.handleGet())
	default:
		w.WriteHeader(http.StatusInternalServerError)
	}
}

func (s *server) handleGet() []byte {
	return s.Data
}

func (s *server) handlePost(r *http.Request) {
	data, err := ioutil.ReadAll(r.Body)
	defer r.Body.Close()

	if err == nil {
		s.Data = data
	}
}

func NewStringSet(values ...string) map[string]struct{} {
	set := make(map[string]struct{}, len(values))
	for _, value := range values {
		set[value] = struct{}{}
	}

	return set
}
